@@ -1,6 +1,8 @@
 package AnyEvent::Radius;
 # DUMMY
-our $VERSION = '1.0';
+use strict;
+use warnings;
+our $VERSION = '1.0.1';
 1;
 
 __END__
@@ -46,4 +48,11 @@ Sergey Leschenko <sergle.ua at gmail.com>
 
 PortaOne Development Team <perl-radius at portaone.com> is the current module's maintainer at CPAN.
 
+=head1 COPYRIGHT & LICENSE
+ 
+Copyright 2016 PortaOne Inc., all rights reserved.
+ 
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
 =cut
